window.Gleam.initSearch([{"doc":"morse_code_translator","title":"morse_code_translator","content":"# Morse Code Translator\n\n[![Package Version](https://img.shields.io/hexpm/v/morse_code_translator)](https://hex.pm/packages/morse_code_translator)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/morse_code_translator/)\n\n## Links\n\n* Homepage: [salif.github.io/morse-code-translator](https://salif.github.io/morse-code-translator/)\n* GitHub: [github.com/salif/morse-code-translator](https://github.com/salif/morse-code-translator)\n* Codeberg: [codeberg.org/salif/morse-code-translator](https://codeberg.org/salif/morse-code-translator)\n\n## Usage\n\n```sh\ngleam add morse_code_translator\n```\n\n```gleam\nimport gleam/io\nimport gleam/option.{None, Some}\nimport morse_code_translator as mct\n\npub fn main() {\n   let demo_encode_options =\n      mct.EncodeOptions(\n         output_dot: None,\n         output_dash: None,\n         output_space: None,\n         output_separator: None,\n         is_uppercase: None,\n         language_num: None,\n      )\n\n   let demo_decode_options =\n      mct.DecodeOptions(\n         input_dot: None,\n         input_dash: None,\n         input_space: None,\n         input_separator: None,\n         to_uppercase: None,\n         language_num: None,\n      )\n\n   let demo_encode: Result(String, mct.MorseCodeError) =\n      mct.encode(&quot; Test &quot;, demo_encode_options, None)\n   io.debug(demo_encode)\n   // Ok(&quot;/ - . ... - /&quot;)\n\n   let demo_decode: Result(String, mct.MorseCodeError) =\n      mct.decode(&quot;/ - . ... - /&quot;, demo_decode_options, None)\n   io.debug(demo_decode)\n   // Ok(&quot; test &quot;)\n\n   &quot;demo&quot;\n   |&gt; mct.encode_to_string(demo_encode_options, None)\n   |&gt; mct.decode_to_string(demo_decode_options, None)\n   |&gt; io.debug\n   // &quot;demo&quot;\n\n   &quot;_.. . __ ___&quot;\n   |&gt; mct.decode_to_string(\n      mct.DecodeOptions(\n         ..demo_decode_options,\n         input_dash: Some(&quot;_&quot;),\n         language_num: Some(mct.language_num_cyrillic),\n      ),\n      None,\n   )\n   |&gt; io.debug\n   // &quot;демо&quot;\n\n   let demo_convert_options =\n      mct.ConvertOptions(\n         input_dot: mct.default_dot,\n         output_dot: &quot;0&quot;,\n         input_dash: mct.default_dash,\n         output_dash: &quot;1&quot;,\n         input_space: mct.default_space,\n         output_space: mct.default_space,\n         input_separator: mct.default_separator,\n         output_separator: mct.default_separator,\n      )\n\n   &quot;-.. . -- ---&quot;\n   |&gt; mct.convert(demo_convert_options)\n   |&gt; io.debug\n   // Ok(&quot;100 0 11 111&quot;)\n\n   &quot;=&quot;\n   |&gt; mct.convert_to_string(demo_convert_options)\n   |&gt; io.debug\n   // &quot;Invalid morse code symbol: =&quot;\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/morse_code_translator&gt;.\n\n## Development\n\n```sh\ngleam build\n```\n","url":"index.html"},{"doc":"characters","title":"base_characters","content":"pub const base_characters: List(#(String, String, List(Bool))) = [\n   #(&quot;1&quot;, &quot;A&quot;, [False, True]),\n   #(&quot;1&quot;, &quot;B&quot;, [True, False, False, False]),\n   #(&quot;1&quot;, &quot;C&quot;, [True, False, True, False]),\n   #(&quot;1&quot;, &quot;D&quot;, [True, False, False]),\n   #(&quot;1&quot;, &quot;E&quot;, [False]),\n   #(&quot;1&quot;, &quot;F&quot;, [False, False, True, False]),\n   #(&quot;1&quot;, &quot;G&quot;, [True, True, False]),\n   #(&quot;1&quot;, &quot;H&quot;, [False, False, False, False]),\n   #(&quot;1&quot;, &quot;I&quot;, [False, False]),\n   #(&quot;1&quot;, &quot;J&quot;, [False, True, True, True]),\n   #(&quot;1&quot;, &quot;K&quot;, [True, False, True]),\n   #(&quot;1&quot;, &quot;L&quot;, [False, True, False, False]),\n   #(&quot;1&quot;, &quot;M&quot;, [True, True]),\n   #(&quot;1&quot;, &quot;N&quot;, [True, False]),\n   #(&quot;1&quot;, &quot;O&quot;, [True, True, True]),\n   #(&quot;1&quot;, &quot;P&quot;, [False, True, True, False]),\n   #(&quot;1&quot;, &quot;Q&quot;, [True, True, False, True]),\n   #(&quot;1&quot;, &quot;R&quot;, [False, True, False]),\n   #(&quot;1&quot;, &quot;S&quot;, [False, False, False]),\n   #(&quot;1&quot;, &quot;T&quot;, [True]),\n   #(&quot;1&quot;, &quot;U&quot;, [False, False, True]),\n   #(&quot;1&quot;, &quot;V&quot;, [False, False, False, True]),\n   #(&quot;1&quot;, &quot;W&quot;, [False, True, True]),\n   #(&quot;1&quot;, &quot;X&quot;, [True, False, False, True]),\n   #(&quot;1&quot;, &quot;Y&quot;, [True, False, True, True]),\n   #(&quot;1&quot;, &quot;Z&quot;, [True, True, False, False]),\n   #(&quot;2&quot;, &quot;0&quot;, [True, True, True, True, True]),\n   #(&quot;2&quot;, &quot;1&quot;, [False, True, True, True, True]),\n   #(&quot;2&quot;, &quot;2&quot;, [False, False, True, True, True]),\n   #(&quot;2&quot;, &quot;3&quot;, [False, False, False, True, True]),\n   #(&quot;2&quot;, &quot;4&quot;, [False, False, False, False, True]),\n   #(&quot;2&quot;, &quot;5&quot;, [False, False, False, False, False]),\n   #(&quot;2&quot;, &quot;6&quot;, [True, False, False, False, False]),\n   #(&quot;2&quot;, &quot;7&quot;, [True, True, False, False, False]),\n   #(&quot;2&quot;, &quot;8&quot;, [True, True, True, False, False]),\n   #(&quot;2&quot;, &quot;9&quot;, [True, True, True, True, False]),\n   #(&quot;3&quot;, &quot;.&quot;, [False, True, False, True, False, True]),\n   #(&quot;3&quot;, &quot;,&quot;, [True, True, False, False, True, True]),\n   #(&quot;3&quot;, &quot;?&quot;, [False, False, True, True, False, False]),\n   #(&quot;3&quot;, &quot;&#39;&quot;, [False, True, True, True, True, False]),\n   #(&quot;3&quot;, &quot;!&quot;, [True, False, True, False, True, True]),\n   #(&quot;3&quot;, &quot;/&quot;, [True, False, False, True, False]),\n   #(&quot;3&quot;, &quot;(&quot;, [True, False, True, True, False]),\n   #(&quot;3&quot;, &quot;)&quot;, [True, False, True, True, False, True]),\n   #(&quot;3&quot;, &quot;&amp;&quot;, [False, True, False, False, False]),\n   #(&quot;3&quot;, &quot;:&quot;, [True, True, True, False, False, False]),\n   #(&quot;3&quot;, &quot;;&quot;, [True, False, True, False, True, False]),\n   #(&quot;3&quot;, &quot;=&quot;, [True, False, False, False, True]),\n   #(&quot;3&quot;, &quot;+&quot;, [False, True, False, True, False]),\n   #(&quot;3&quot;, &quot;-&quot;, [True, False, False, False, False, True]),\n   #(&quot;3&quot;, &quot;_&quot;, [False, False, True, True, False, True]),\n   #(&quot;3&quot;, &quot;\\&quot;&quot;, [False, True, False, False, True, False]),\n   #(&quot;3&quot;, &quot;$&quot;, [False, False, False, True, False, False, True]),\n   #(&quot;3&quot;, &quot;@&quot;, [False, True, True, False, True, False]),\n   #(&quot;3&quot;, &quot;¿&quot;, [False, False, True, False, True]),\n   #(&quot;3&quot;, &quot;¡&quot;, [True, True, False, False, False, True]),\n   #(&quot;4&quot;, &quot;Ã&quot;, [False, True, True, False, True]),\n   #(&quot;4&quot;, &quot;Á&quot;, [False, True, True, False, True]),\n   #(&quot;4&quot;, &quot;Å&quot;, [False, True, True, False, True]),\n   #(&quot;4&quot;, &quot;À&quot;, [False, True, True, False, True]),\n   #(&quot;4&quot;, &quot;Â&quot;, [False, True, True, False, True]),\n   #(&quot;4&quot;, &quot;Ä&quot;, [False, True, False, True]),\n   #(&quot;4&quot;, &quot;Ą&quot;, [False, True, False, True]),\n   #(&quot;4&quot;, &quot;Æ&quot;, [False, True, False, True]),\n   #(&quot;4&quot;, &quot;Ç&quot;, [True, False, True, False, False]),\n   #(&quot;4&quot;, &quot;Ć&quot;, [True, False, True, False, False]),\n   #(&quot;4&quot;, &quot;Ĉ&quot;, [True, False, True, False, False]),\n   #(&quot;4&quot;, &quot;Č&quot;, [True, True, False]),\n   #(&quot;4&quot;, &quot;Ð&quot;, [False, False, True, True, False]),\n   #(&quot;4&quot;, &quot;È&quot;, [False, True, False, False, True]),\n   #(&quot;4&quot;, &quot;Ę&quot;, [False, False, True, False, False]),\n   #(&quot;4&quot;, &quot;Ë&quot;, [False, False, True, False, False]),\n   #(&quot;4&quot;, &quot;É&quot;, [False, False, True, False, False]),\n   #(&quot;4&quot;, &quot;Ê&quot;, [True, False, False, True, False]),\n   #(&quot;4&quot;, &quot;Ğ&quot;, [True, True, False, True, False]),\n   #(&quot;4&quot;, &quot;Ĝ&quot;, [True, True, False, True, False]),\n   #(&quot;4&quot;, &quot;Ĥ&quot;, [True, True, True, True]),\n   #(&quot;4&quot;, &quot;İ&quot;, [False, True, False, False, True]),\n   #(&quot;4&quot;, &quot;Ï&quot;, [True, False, False, True, True]),\n   #(&quot;4&quot;, &quot;Ì&quot;, [False, True, True, True, False]),\n   #(&quot;4&quot;, &quot;Ĵ&quot;, [False, True, True, True, False]),\n   #(&quot;4&quot;, &quot;Ł&quot;, [False, True, False, False, True]),\n   #(&quot;4&quot;, &quot;Ń&quot;, [True, True, False, True, True]),\n   #(&quot;4&quot;, &quot;Ñ&quot;, [True, True, False, True, True]),\n   #(&quot;4&quot;, &quot;Ó&quot;, [True, True, True, False]),\n   #(&quot;4&quot;, &quot;Ò&quot;, [True, True, True, False]),\n   #(&quot;4&quot;, &quot;Ö&quot;, [True, True, True, False]),\n   #(&quot;4&quot;, &quot;Ô&quot;, [True, True, True, False]),\n   #(&quot;4&quot;, &quot;Ø&quot;, [True, True, True, False]),\n   #(&quot;4&quot;, &quot;Ś&quot;, [False, False, False, True, False, False, False]),\n   #(&quot;4&quot;, &quot;Ş&quot;, [False, True, True, False, False]),\n   #(&quot;4&quot;, &quot;Ș&quot;, [True, True, True, True]),\n   #(&quot;4&quot;, &quot;Š&quot;, [True, True, True, True]),\n   #(&quot;4&quot;, &quot;Ŝ&quot;, [False, False, False, True, False]),\n   #(&quot;4&quot;, &quot;ß&quot;, [False, False, False, False, False, False]),\n   #(&quot;4&quot;, &quot;Þ&quot;, [False, True, True, False, False]),\n   #(&quot;4&quot;, &quot;Ü&quot;, [False, False, True, True]),\n   #(&quot;4&quot;, &quot;Ù&quot;, [False, False, True, True]),\n   #(&quot;4&quot;, &quot;Ŭ&quot;, [False, False, True, True]),\n   #(&quot;4&quot;, &quot;Ž&quot;, [True, True, False, False, True]),\n   #(&quot;4&quot;, &quot;Ź&quot;, [True, True, False, False, True, False]),\n   #(&quot;4&quot;, &quot;Ż&quot;, [True, True, False, False, True]),\n   #(&quot;5&quot;, &quot;А&quot;, [False, True]),\n   #(&quot;5&quot;, &quot;Б&quot;, [True, False, False, False]),\n   #(&quot;5&quot;, &quot;В&quot;, [False, True, True]),\n   #(&quot;5&quot;, &quot;Г&quot;, [True, True, False]),\n   #(&quot;5&quot;, &quot;Д&quot;, [True, False, False]),\n   #(&quot;5&quot;, &quot;Е&quot;, [False]),\n   #(&quot;5&quot;, &quot;Ж&quot;, [False, False, False, True]),\n   #(&quot;5&quot;, &quot;З&quot;, [True, True, False, False]),\n   #(&quot;5&quot;, &quot;И&quot;, [False, False]),\n   #(&quot;5&quot;, &quot;Й&quot;, [False, True, True, True]),\n   #(&quot;5&quot;, &quot;К&quot;, [True, False, True]),\n   #(&quot;5&quot;, &quot;Л&quot;, [False, True, False, False]),\n   #(&quot;5&quot;, &quot;М&quot;, [True, True]),\n   #(&quot;5&quot;, &quot;Н&quot;, [True, False]),\n   #(&quot;5&quot;, &quot;О&quot;, [True, True, True]),\n   #(&quot;5&quot;, &quot;П&quot;, [False, True, True, False]),\n   #(&quot;5&quot;, &quot;Р&quot;, [False, True, False]),\n   #(&quot;5&quot;, &quot;С&quot;, [False, False, False]),\n   #(&quot;5&quot;, &quot;Т&quot;, [True]),\n   #(&quot;5&quot;, &quot;У&quot;, [False, False, True]),\n   #(&quot;5&quot;, &quot;Ф&quot;, [False, False, True, False]),\n   #(&quot;5&quot;, &quot;Х&quot;, [False, False, False, False]),\n   #(&quot;5&quot;, &quot;Ц&quot;, [True, False, True, False]),\n   #(&quot;5&quot;, &quot;Ч&quot;, [True, True, True, False]),\n   #(&quot;5&quot;, &quot;Ш&quot;, [True, True, True, True]),\n   #(&quot;5&quot;, &quot;Щ&quot;, [True, True, False, True]),\n   #(&quot;5&quot;, &quot;Ъ&quot;, [True, True, False, True, True]),\n   #(&quot;5&quot;, &quot;Ы&quot;, [True, False, True, True]),\n   #(&quot;5&quot;, &quot;Ь&quot;, [True, False, False, True]),\n   #(&quot;5&quot;, &quot;Э&quot;, [False, False, True, False, False]),\n   #(&quot;5&quot;, &quot;Ю&quot;, [False, False, True, True]),\n   #(&quot;5&quot;, &quot;Я&quot;, [False, True, False, True]),\n   #(&quot;5&quot;, &quot;Ї&quot;, [False, True, True, True, False]),\n   #(&quot;5&quot;, &quot;Є&quot;, [False, False, True, False, False]),\n   #(&quot;5&quot;, &quot;І&quot;, [False, False]),\n   #(&quot;5&quot;, &quot;Ґ&quot;, [True, True, False]),\n   #(&quot;6&quot;, &quot;Α&quot;, [False, True]),\n   #(&quot;6&quot;, &quot;Β&quot;, [True, False, False, False]),\n   #(&quot;6&quot;, &quot;Γ&quot;, [True, True, False]),\n   #(&quot;6&quot;, &quot;Δ&quot;, [True, False, False]),\n   #(&quot;6&quot;, &quot;Ε&quot;, [False]),\n   #(&quot;6&quot;, &quot;Ζ&quot;, [True, True, False, False]),\n   #(&quot;6&quot;, &quot;Η&quot;, [False, False, False, False]),\n   #(&quot;6&quot;, &quot;Θ&quot;, [True, False, True, False]),\n   #(&quot;6&quot;, &quot;Ι&quot;, [False, False]),\n   #(&quot;6&quot;, &quot;Κ&quot;, [True, False, True]),\n   #(&quot;6&quot;, &quot;Λ&quot;, [False, True, False, False]),\n   #(&quot;6&quot;, &quot;Μ&quot;, [True, True]),\n   #(&quot;6&quot;, &quot;Ν&quot;, [True, False]),\n   #(&quot;6&quot;, &quot;Ξ&quot;, [True, False, False, True]),\n   #(&quot;6&quot;, &quot;Ο&quot;, [True, True, True]),\n   #(&quot;6&quot;, &quot;Π&quot;, [False, True, True, False]),\n   #(&quot;6&quot;, &quot;Ρ&quot;, [False, True, False]),\n   #(&quot;6&quot;, &quot;Σ&quot;, [False, False, False]),\n   #(&quot;6&quot;, &quot;Τ&quot;, [True]),\n   #(&quot;6&quot;, &quot;Υ&quot;, [True, False, True, True]),\n   #(&quot;6&quot;, &quot;Φ&quot;, [False, False, True, False]),\n   #(&quot;6&quot;, &quot;Χ&quot;, [True, True, True, True]),\n   #(&quot;6&quot;, &quot;Ψ&quot;, [True, True, False, True]),\n   #(&quot;6&quot;, &quot;Ω&quot;, [False, True, True]),\n   #(&quot;7&quot;, &quot;א&quot;, [False, True]),\n   #(&quot;7&quot;, &quot;ב&quot;, [True, False, False, False]),\n   #(&quot;7&quot;, &quot;ג&quot;, [True, True, False]),\n   #(&quot;7&quot;, &quot;ד&quot;, [True, False, False]),\n   #(&quot;7&quot;, &quot;ה&quot;, [True, True, True]),\n   #(&quot;7&quot;, &quot;ו&quot;, [False]),\n   #(&quot;7&quot;, &quot;ז&quot;, [True, True, False, False]),\n   #(&quot;7&quot;, &quot;ח&quot;, [False, False, False, False]),\n   #(&quot;7&quot;, &quot;ט&quot;, [False, False, True]),\n   #(&quot;7&quot;, &quot;י&quot;, [False, False]),\n   #(&quot;7&quot;, &quot;כ&quot;, [True, False, True]),\n   #(&quot;7&quot;, &quot;ל&quot;, [False, True, False, False]),\n   #(&quot;7&quot;, &quot;מ&quot;, [True, True]),\n   #(&quot;7&quot;, &quot;נ&quot;, [True, False]),\n   #(&quot;7&quot;, &quot;ס&quot;, [True, False, True, False]),\n   #(&quot;7&quot;, &quot;ע&quot;, [False, True, True, True]),\n   #(&quot;7&quot;, &quot;פ&quot;, [False, True, True, False]),\n   #(&quot;7&quot;, &quot;צ&quot;, [False, True, True]),\n   #(&quot;7&quot;, &quot;ק&quot;, [True, True, False, True]),\n   #(&quot;7&quot;, &quot;ר&quot;, [False, True, False]),\n   #(&quot;7&quot;, &quot;ש&quot;, [False, False, False]),\n   #(&quot;7&quot;, &quot;ת&quot;, [True]),\n   #(&quot;8&quot;, &quot;ا&quot;, [False, True]),\n   #(&quot;8&quot;, &quot;ب&quot;, [True, False, False, False]),\n   #(&quot;8&quot;, &quot;ت&quot;, [True]),\n   #(&quot;8&quot;, &quot;ث&quot;, [True, False, True, False]),\n   #(&quot;8&quot;, &quot;ج&quot;, [False, True, True, True]),\n   #(&quot;8&quot;, &quot;ح&quot;, [False, False, False, False]),\n   #(&quot;8&quot;, &quot;خ&quot;, [True, True, True]),\n   #(&quot;8&quot;, &quot;د&quot;, [True, False, False]),\n   #(&quot;8&quot;, &quot;ذ&quot;, [True, True, False, False]),\n   #(&quot;8&quot;, &quot;ر&quot;, [False, True, False]),\n   #(&quot;8&quot;, &quot;ز&quot;, [True, True, True, False]),\n   #(&quot;8&quot;, &quot;س&quot;, [False, False, False]),\n   #(&quot;8&quot;, &quot;ش&quot;, [True, True, True, True]),\n   #(&quot;8&quot;, &quot;ص&quot;, [True, False, False, True]),\n   #(&quot;8&quot;, &quot;ض&quot;, [False, False, False, True]),\n   #(&quot;8&quot;, &quot;ط&quot;, [False, False, True]),\n   #(&quot;8&quot;, &quot;ظ&quot;, [True, False, True, True]),\n   #(&quot;8&quot;, &quot;ع&quot;, [False, True, False, True]),\n   #(&quot;8&quot;, &quot;غ&quot;, [True, True, False]),\n   #(&quot;8&quot;, &quot;ف&quot;, [False, False, True, False]),\n   #(&quot;8&quot;, &quot;ق&quot;, [True, True, False, True]),\n   #(&quot;8&quot;, &quot;ك&quot;, [True, False, True]),\n   #(&quot;8&quot;, &quot;ل&quot;, [False, True, False, False]),\n   #(&quot;8&quot;, &quot;م&quot;, [True, True]),\n   #(&quot;8&quot;, &quot;ن&quot;, [True, False]),\n   #(&quot;8&quot;, &quot;ه&quot;, [False, False, True, False, False]),\n   #(&quot;8&quot;, &quot;و&quot;, [False, True, True]),\n   #(&quot;8&quot;, &quot;ي&quot;, [False, False]),\n   #(&quot;8&quot;, &quot;ﺀ&quot;, [False]),\n   #(&quot;9&quot;, &quot;ا&quot;, [False, True]),\n   #(&quot;9&quot;, &quot;ب&quot;, [True, False, False, False]),\n   #(&quot;9&quot;, &quot;پ&quot;, [False, True, True, False]),\n   #(&quot;9&quot;, &quot;ت&quot;, [True]),\n   #(&quot;9&quot;, &quot;ث&quot;, [True, False, True, False]),\n   #(&quot;9&quot;, &quot;ج&quot;, [False, True, True, True]),\n   #(&quot;9&quot;, &quot;چ&quot;, [True, True, True, False]),\n   #(&quot;9&quot;, &quot;ح&quot;, [False, False, False, False]),\n   #(&quot;9&quot;, &quot;خ&quot;, [True, False, False, True]),\n   #(&quot;9&quot;, &quot;د&quot;, [True, False, False]),\n   #(&quot;9&quot;, &quot;ذ&quot;, [False, False, False, True]),\n   #(&quot;9&quot;, &quot;ر&quot;, [False, True, False]),\n   #(&quot;9&quot;, &quot;ز&quot;, [True, True, False, False]),\n   #(&quot;9&quot;, &quot;ژ&quot;, [True, True, False]),\n   #(&quot;9&quot;, &quot;س&quot;, [False, False, False]),\n   #(&quot;9&quot;, &quot;ش&quot;, [True, True, True, True]),\n   #(&quot;9&quot;, &quot;ص&quot;, [False, True, False, True]),\n   #(&quot;9&quot;, &quot;ض&quot;, [False, False, True, False, False]),\n   #(&quot;9&quot;, &quot;ط&quot;, [False, False, True]),\n   #(&quot;9&quot;, &quot;ظ&quot;, [True, False, True, True]),\n   #(&quot;9&quot;, &quot;ع&quot;, [True, True, True]),\n   #(&quot;9&quot;, &quot;غ&quot;, [False, False, True, True]),\n   #(&quot;9&quot;, &quot;ف&quot;, [False, False, True, False]),\n   #(&quot;9&quot;, &quot;ق&quot;, [True, True, True, False, False, False]),\n   #(&quot;9&quot;, &quot;ک&quot;, [True, False, True]),\n   #(&quot;9&quot;, &quot;گ&quot;, [True, True, False, True]),\n   #(&quot;9&quot;, &quot;ل&quot;, [False, True, False, False]),\n   #(&quot;9&quot;, &quot;م&quot;, [True, True]),\n   #(&quot;9&quot;, &quot;ن&quot;, [True, False]),\n   #(&quot;9&quot;, &quot;و&quot;, [False, True, True]),\n   #(&quot;9&quot;, &quot;ه&quot;, [False]),\n   #(&quot;9&quot;, &quot;ی&quot;, [False, False]),\n   #(&quot;10&quot;, &quot;ア&quot;, [True, True, False, True, True]),\n   #(&quot;10&quot;, &quot;カ&quot;, [False, True, False, False]),\n   #(&quot;10&quot;, &quot;サ&quot;, [True, False, True, False, True]),\n   #(&quot;10&quot;, &quot;タ&quot;, [True, False]),\n   #(&quot;10&quot;, &quot;ナ&quot;, [False, True, False]),\n   #(&quot;10&quot;, &quot;ハ&quot;, [True, False, False, False]),\n   #(&quot;10&quot;, &quot;マ&quot;, [True, False, False, True]),\n   #(&quot;10&quot;, &quot;ヤ&quot;, [False, True, True]),\n   #(&quot;10&quot;, &quot;ラ&quot;, [False, False, False]),\n   #(&quot;10&quot;, &quot;ワ&quot;, [True, False, True]),\n   #(&quot;10&quot;, &quot;イ&quot;, [False, True]),\n   #(&quot;10&quot;, &quot;キ&quot;, [True, False, True, False, False]),\n   #(&quot;10&quot;, &quot;シ&quot;, [True, True, False, True, False]),\n   #(&quot;10&quot;, &quot;チ&quot;, [False, False, True, False]),\n   #(&quot;10&quot;, &quot;ニ&quot;, [True, False, True, False]),\n   #(&quot;10&quot;, &quot;ヒ&quot;, [True, True, False, False, True]),\n   #(&quot;10&quot;, &quot;ミ&quot;, [False, False, True, False, True]),\n   #(&quot;10&quot;, &quot;リ&quot;, [True, True, False]),\n   #(&quot;10&quot;, &quot;ヰ&quot;, [False, True, False, False, True]),\n   #(&quot;10&quot;, &quot;ウ&quot;, [False, False, True]),\n   #(&quot;10&quot;, &quot;ク&quot;, [False, False, False, True]),\n   #(&quot;10&quot;, &quot;ス&quot;, [True, True, True, False, True]),\n   #(&quot;10&quot;, &quot;ツ&quot;, [False, True, True, False]),\n   #(&quot;10&quot;, &quot;ヌ&quot;, [False, False, False, False]),\n   #(&quot;10&quot;, &quot;フ&quot;, [True, True, False, False]),\n   #(&quot;10&quot;, &quot;ム&quot;, [True]),\n   #(&quot;10&quot;, &quot;ユ&quot;, [True, False, False, True, True]),\n   #(&quot;10&quot;, &quot;ル&quot;, [True, False, True, True, False]),\n   #(&quot;10&quot;, &quot;ン&quot;, [False, True, False, True, False]),\n   #(&quot;10&quot;, &quot;エ&quot;, [True, False, True, True, True]),\n   #(&quot;10&quot;, &quot;ケ&quot;, [True, False, True, True]),\n   #(&quot;10&quot;, &quot;セ&quot;, [False, True, True, True, False]),\n   #(&quot;10&quot;, &quot;テ&quot;, [False, True, False, True, True]),\n   #(&quot;10&quot;, &quot;ネ&quot;, [True, True, False, True]),\n   #(&quot;10&quot;, &quot;ヘ&quot;, [False]),\n   #(&quot;10&quot;, &quot;メ&quot;, [True, False, False, False, True]),\n   #(&quot;10&quot;, &quot;レ&quot;, [True, True, True]),\n   #(&quot;10&quot;, &quot;ヱ&quot;, [False, True, True, False, False]),\n   #(&quot;10&quot;, &quot;オ&quot;, [False, True, False, False, False]),\n   #(&quot;10&quot;, &quot;コ&quot;, [True, True, True, True]),\n   #(&quot;10&quot;, &quot;ソ&quot;, [True, True, True, False]),\n   #(&quot;10&quot;, &quot;ト&quot;, [False, False, True, False, False]),\n   #(&quot;10&quot;, &quot;ノ&quot;, [False, False, True, True]),\n   #(&quot;10&quot;, &quot;ホ&quot;, [True, False, False]),\n   #(&quot;10&quot;, &quot;モ&quot;, [True, False, False, True, False]),\n   #(&quot;10&quot;, &quot;ヨ&quot;, [True, True]),\n   #(&quot;10&quot;, &quot;ロ&quot;, [False, True, False, True]),\n   #(&quot;10&quot;, &quot;ヲ&quot;, [False, True, True, True]),\n   #(&quot;10&quot;, &quot;゛&quot;, [False, False]),\n   #(&quot;10&quot;, &quot;゜&quot;, [False, False, True, True, False]),\n   #(&quot;10&quot;, &quot;。&quot;, [False, True, False, True, False, False]),\n   #(&quot;10&quot;, &quot;ー&quot;, [False, True, True, False, True]),\n   #(&quot;10&quot;, &quot;、&quot;, [False, True, False, True, False, True]),\n   #(&quot;10&quot;, &quot;（&quot;, [True, False, True, True, False, True]),\n   #(&quot;10&quot;, &quot;）&quot;, [False, True, False, False, True, False]),\n   #(&quot;11&quot;, &quot;ㄱ&quot;, [False, True, False, False]),\n   #(&quot;11&quot;, &quot;ㄴ&quot;, [False, False, True, False]),\n   #(&quot;11&quot;, &quot;ㄷ&quot;, [True, False, False, False]),\n   #(&quot;11&quot;, &quot;ㄹ&quot;, [False, False, False, True]),\n   #(&quot;11&quot;, &quot;ㅁ&quot;, [True, True]),\n   #(&quot;11&quot;, &quot;ㅂ&quot;, [False, True, True]),\n   #(&quot;11&quot;, &quot;ㅅ&quot;, [True, True, False]),\n   #(&quot;11&quot;, &quot;ㅇ&quot;, [True, False, True]),\n   #(&quot;11&quot;, &quot;ㅈ&quot;, [False, True, True, False]),\n   #(&quot;11&quot;, &quot;ㅊ&quot;, [True, False, True, False]),\n   #(&quot;11&quot;, &quot;ㅋ&quot;, [True, False, False, True]),\n   #(&quot;11&quot;, &quot;ㅌ&quot;, [True, True, False, False]),\n   #(&quot;11&quot;, &quot;ㅍ&quot;, [True, True, True]),\n   #(&quot;11&quot;, &quot;ㅎ&quot;, [False, True, True, True]),\n   #(&quot;11&quot;, &quot;ㅏ&quot;, [False]),\n   #(&quot;11&quot;, &quot;ㅑ&quot;, [False, False]),\n   #(&quot;11&quot;, &quot;ㅓ&quot;, [True]),\n   #(&quot;11&quot;, &quot;ㅕ&quot;, [False, False, False]),\n   #(&quot;11&quot;, &quot;ㅗ&quot;, [False, True]),\n   #(&quot;11&quot;, &quot;ㅛ&quot;, [True, False]),\n   #(&quot;11&quot;, &quot;ㅜ&quot;, [False, False, False, False]),\n   #(&quot;11&quot;, &quot;ㅠ&quot;, [False, True, False]),\n   #(&quot;11&quot;, &quot;ㅡ&quot;, [True, False, False]),\n   #(&quot;11&quot;, &quot;ㅣ&quot;, [False, False, True]),\n   #(&quot;12&quot;, &quot;ก&quot;, [True, True, False]),\n   #(&quot;12&quot;, &quot;ข&quot;, [True, False, True, False]),\n   #(&quot;12&quot;, &quot;ค&quot;, [True, False, True]),\n   #(&quot;12&quot;, &quot;ง&quot;, [True, False, True, True, False]),\n   #(&quot;12&quot;, &quot;จ&quot;, [True, False, False, True, False]),\n   #(&quot;12&quot;, &quot;ฉ&quot;, [True, True, True, True]),\n   #(&quot;12&quot;, &quot;ช&quot;, [True, False, False, True]),\n   #(&quot;12&quot;, &quot;ซ&quot;, [True, True, False, False]),\n   #(&quot;12&quot;, &quot;ญ&quot;, [False, True, True, True]),\n   #(&quot;12&quot;, &quot;ด&quot;, [True, False, False]),\n   #(&quot;12&quot;, &quot;ต&quot;, [True]),\n   #(&quot;12&quot;, &quot;ถ&quot;, [True, False, True, False, False]),\n   #(&quot;12&quot;, &quot;ท&quot;, [True, False, False, True, True]),\n   #(&quot;12&quot;, &quot;น&quot;, [True, False]),\n   #(&quot;12&quot;, &quot;บ&quot;, [True, False, False, False]),\n   #(&quot;12&quot;, &quot;ป&quot;, [False, True, True, False]),\n   #(&quot;12&quot;, &quot;ผ&quot;, [True, True, False, True]),\n   #(&quot;12&quot;, &quot;ฝ&quot;, [True, False, True, False, True]),\n   #(&quot;12&quot;, &quot;พ&quot;, [False, True, True, False, False]),\n   #(&quot;12&quot;, &quot;ฟ&quot;, [False, False, True, False]),\n   #(&quot;12&quot;, &quot;ม&quot;, [True, True]),\n   #(&quot;12&quot;, &quot;ย&quot;, [True, False, True, True]),\n   #(&quot;12&quot;, &quot;ร&quot;, [False, True, False]),\n   #(&quot;12&quot;, &quot;ล&quot;, [False, True, False, False]),\n   #(&quot;12&quot;, &quot;ว&quot;, [False, True, True]),\n   #(&quot;12&quot;, &quot;ส&quot;, [False, False, False]),\n   #(&quot;12&quot;, &quot;ห&quot;, [False, False, False, False]),\n   #(&quot;12&quot;, &quot;อ&quot;, [True, False, False, False, True]),\n   #(&quot;12&quot;, &quot;ฮ&quot;, [True, True, False, True, True]),\n   #(&quot;12&quot;, &quot;ฤ&quot;, [False, True, False, True, True]),\n   #(&quot;12&quot;, &quot;ะ&quot;, [False, True, False, False, False]),\n   #(&quot;12&quot;, &quot;า&quot;, [False, True]),\n   #(&quot;12&quot;, &quot;ิ&quot;, [False, False, True, False, False]),\n   #(&quot;12&quot;, &quot;ี&quot;, [False, False]),\n   #(&quot;12&quot;, &quot;ึ&quot;, [False, False, True, True, False]),\n   #(&quot;12&quot;, &quot;ื&quot;, [False, False, True, True]),\n   #(&quot;12&quot;, &quot;ุ&quot;, [False, False, True, False, True]),\n   #(&quot;12&quot;, &quot;ู&quot;, [True, True, True, False]),\n   #(&quot;12&quot;, &quot;เ&quot;, [False]),\n   #(&quot;12&quot;, &quot;แ&quot;, [False, True, False, True]),\n   #(&quot;12&quot;, &quot;ไ&quot;, [False, True, False, False, True]),\n   #(&quot;12&quot;, &quot;โ&quot;, [True, True, True]),\n   #(&quot;12&quot;, &quot;ำ&quot;, [False, False, False, True, False]),\n   #(&quot;12&quot;, &quot;่&quot;, [False, False, True]),\n   #(&quot;12&quot;, &quot;้&quot;, [False, False, False, True]),\n   #(&quot;12&quot;, &quot;๊&quot;, [True, True, False, False, False]),\n   #(&quot;12&quot;, &quot;๋&quot;, [False, True, False, True, False]),\n   #(&quot;12&quot;, &quot;ั&quot;, [False, True, True, False, True]),\n   #(&quot;12&quot;, &quot;็&quot;, [True, True, True, False, False]),\n   #(&quot;12&quot;, &quot;์&quot;, [True, True, False, False, True]),\n   #(&quot;12&quot;, &quot;ๆ&quot;, [True, False, True, True, True]),\n   #(&quot;12&quot;, &quot;ฯ&quot;, [True, True, False, True, False]),\n]\n\nSynonyms:\ncharacters.base_characters\ncharacters base_characters","url":"characters.html#base_characters"},{"doc":"characters","title":"characters","content":"","url":"characters.html"},{"doc":"morse_code_translator","title":"ConvertOptions","content":"pub type ConvertOptions {\n   ConvertOptions(\n      input_dot: String,\n      output_dot: String,\n      input_dash: String,\n      output_dash: String,\n      input_space: String,\n      output_space: String,\n      input_separator: String,\n      output_separator: String,\n   )\n}\n\nConvertOptions(\n   input_dot: String,\n   output_dot: String,\n   input_dash: String,\n   output_dash: String,\n   input_space: String,\n   output_space: String,\n   input_separator: String,\n   output_separator: String,\n)\n\n\nSynonyms:\nmorse_code_translator.ConvertOptions\nmorse_code_translator ConvertOptions","url":"morse_code_translator.html#ConvertOptions"},{"doc":"morse_code_translator","title":"DecodeOptions","content":"pub type DecodeOptions {\n   DecodeOptions(\n      input_dot: option.Option(String),\n      input_dash: option.Option(String),\n      input_space: option.Option(String),\n      input_separator: option.Option(String),\n      to_uppercase: option.Option(Bool),\n      language_num: option.Option(String),\n   )\n}\n\nDecodeOptions(\n   input_dot: option.Option(String),\n   input_dash: option.Option(String),\n   input_space: option.Option(String),\n   input_separator: option.Option(String),\n   to_uppercase: option.Option(Bool),\n   language_num: option.Option(String),\n)\n\n\nSynonyms:\nmorse_code_translator.DecodeOptions\nmorse_code_translator DecodeOptions","url":"morse_code_translator.html#DecodeOptions"},{"doc":"morse_code_translator","title":"EncodeOptions","content":"pub type EncodeOptions {\n   EncodeOptions(\n      output_dot: option.Option(String),\n      output_dash: option.Option(String),\n      output_space: option.Option(String),\n      output_separator: option.Option(String),\n      is_uppercase: option.Option(Bool),\n      language_num: option.Option(String),\n   )\n}\n\nEncodeOptions(\n   output_dot: option.Option(String),\n   output_dash: option.Option(String),\n   output_space: option.Option(String),\n   output_separator: option.Option(String),\n   is_uppercase: option.Option(Bool),\n   language_num: option.Option(String),\n)\n\n\nSynonyms:\nmorse_code_translator.EncodeOptions\nmorse_code_translator EncodeOptions","url":"morse_code_translator.html#EncodeOptions"},{"doc":"morse_code_translator","title":"MorseCodeError","content":"pub type MorseCodeError {\n   MorseCodeError(msg: String)\n}\n\nMorseCodeError(msg: String)\n\n\nSynonyms:\nmorse_code_translator.MorseCodeError\nmorse_code_translator MorseCodeError","url":"morse_code_translator.html#MorseCodeError"},{"doc":"morse_code_translator","title":"MorseCodeList","content":"pub type MorseCodeList =\n   List(#(String, String, List(Bool)))\n\n\nSynonyms:\nmorse_code_translator.MorseCodeList\nmorse_code_translator MorseCodeList","url":"morse_code_translator.html#MorseCodeList"},{"doc":"morse_code_translator","title":"default_dash","content":"pub const default_dash: String = &quot;-&quot;\n\nSynonyms:\nmorse_code_translator.default_dash\nmorse_code_translator default_dash","url":"morse_code_translator.html#default_dash"},{"doc":"morse_code_translator","title":"default_dot","content":"pub const default_dot: String = &quot;.&quot;\n\nSynonyms:\nmorse_code_translator.default_dot\nmorse_code_translator default_dot","url":"morse_code_translator.html#default_dot"},{"doc":"morse_code_translator","title":"default_is_uppercase","content":"pub const default_is_uppercase: Bool = False\n\nSynonyms:\nmorse_code_translator.default_is_uppercase\nmorse_code_translator default_is_uppercase","url":"morse_code_translator.html#default_is_uppercase"},{"doc":"morse_code_translator","title":"default_language_num","content":"pub const default_language_num: String = language_num_latin\n\nSynonyms:\nmorse_code_translator.default_language_num\nmorse_code_translator default_language_num","url":"morse_code_translator.html#default_language_num"},{"doc":"morse_code_translator","title":"default_separator","content":"pub const default_separator: String = &quot; &quot;\n\nSynonyms:\nmorse_code_translator.default_separator\nmorse_code_translator default_separator","url":"morse_code_translator.html#default_separator"},{"doc":"morse_code_translator","title":"default_space","content":"pub const default_space: String = &quot;/&quot;\n\nSynonyms:\nmorse_code_translator.default_space\nmorse_code_translator default_space","url":"morse_code_translator.html#default_space"},{"doc":"morse_code_translator","title":"default_to_uppercase","content":"pub const default_to_uppercase: Bool = False\n\nSynonyms:\nmorse_code_translator.default_to_uppercase\nmorse_code_translator default_to_uppercase","url":"morse_code_translator.html#default_to_uppercase"},{"doc":"morse_code_translator","title":"language_num_arabic","content":"pub const language_num_arabic: String = &quot;8&quot;\n\nSynonyms:\nmorse_code_translator.language_num_arabic\nmorse_code_translator language_num_arabic","url":"morse_code_translator.html#language_num_arabic"},{"doc":"morse_code_translator","title":"language_num_cyrillic","content":"pub const language_num_cyrillic: String = &quot;5&quot;\n\nSynonyms:\nmorse_code_translator.language_num_cyrillic\nmorse_code_translator language_num_cyrillic","url":"morse_code_translator.html#language_num_cyrillic"},{"doc":"morse_code_translator","title":"language_num_greek","content":"pub const language_num_greek: String = &quot;6&quot;\n\nSynonyms:\nmorse_code_translator.language_num_greek\nmorse_code_translator language_num_greek","url":"morse_code_translator.html#language_num_greek"},{"doc":"morse_code_translator","title":"language_num_hebrew","content":"pub const language_num_hebrew: String = &quot;7&quot;\n\nSynonyms:\nmorse_code_translator.language_num_hebrew\nmorse_code_translator language_num_hebrew","url":"morse_code_translator.html#language_num_hebrew"},{"doc":"morse_code_translator","title":"language_num_japanese","content":"pub const language_num_japanese: String = &quot;10&quot;\n\nSynonyms:\nmorse_code_translator.language_num_japanese\nmorse_code_translator language_num_japanese","url":"morse_code_translator.html#language_num_japanese"},{"doc":"morse_code_translator","title":"language_num_korean","content":"pub const language_num_korean: String = &quot;11&quot;\n\nSynonyms:\nmorse_code_translator.language_num_korean\nmorse_code_translator language_num_korean","url":"morse_code_translator.html#language_num_korean"},{"doc":"morse_code_translator","title":"language_num_latin","content":"pub const language_num_latin: String = &quot;1&quot;\n\nSynonyms:\nmorse_code_translator.language_num_latin\nmorse_code_translator language_num_latin","url":"morse_code_translator.html#language_num_latin"},{"doc":"morse_code_translator","title":"language_num_latin_extended","content":"pub const language_num_latin_extended: String = &quot;4&quot;\n\nSynonyms:\nmorse_code_translator.language_num_latin_extended\nmorse_code_translator language_num_latin_extended","url":"morse_code_translator.html#language_num_latin_extended"},{"doc":"morse_code_translator","title":"language_num_numbers","content":"pub const language_num_numbers: String = &quot;2&quot;\n\nSynonyms:\nmorse_code_translator.language_num_numbers\nmorse_code_translator language_num_numbers","url":"morse_code_translator.html#language_num_numbers"},{"doc":"morse_code_translator","title":"language_num_persian","content":"pub const language_num_persian: String = &quot;9&quot;\n\nSynonyms:\nmorse_code_translator.language_num_persian\nmorse_code_translator language_num_persian","url":"morse_code_translator.html#language_num_persian"},{"doc":"morse_code_translator","title":"language_num_punctuation","content":"pub const language_num_punctuation: String = &quot;3&quot;\n\nSynonyms:\nmorse_code_translator.language_num_punctuation\nmorse_code_translator language_num_punctuation","url":"morse_code_translator.html#language_num_punctuation"},{"doc":"morse_code_translator","title":"language_num_thai","content":"pub const language_num_thai: String = &quot;12&quot;\n\nSynonyms:\nmorse_code_translator.language_num_thai\nmorse_code_translator language_num_thai","url":"morse_code_translator.html#language_num_thai"},{"doc":"morse_code_translator","title":"morse_code_list","content":"pub const morse_code_list: List(#(String, String, List(Bool))) = characters.base_characters\n\nSynonyms:\nmorse_code_translator.morse_code_list\nmorse_code_translator morse_code_list","url":"morse_code_translator.html#morse_code_list"},{"doc":"morse_code_translator","title":"convert","content":"pub fn convert(\n   input: String,\n   options: ConvertOptions,\n) -&gt; Result(String, MorseCodeError)\n\nSynonyms:\nmorse_code_translator.convert\nmorse_code_translator convert","url":"morse_code_translator.html#convert"},{"doc":"morse_code_translator","title":"convert_to_string","content":"pub fn convert_to_string(\n   input: String,\n   options: ConvertOptions,\n) -&gt; String\n\nSynonyms:\nmorse_code_translator.convert_to_string\nmorse_code_translator convert_to_string","url":"morse_code_translator.html#convert_to_string"},{"doc":"morse_code_translator","title":"decode","content":"pub fn decode(\n   input: String,\n   options: DecodeOptions,\n   morse_code_dict: Option(List(#(String, String, List(Bool)))),\n) -&gt; Result(String, MorseCodeError)\n\nSynonyms:\nmorse_code_translator.decode\nmorse_code_translator decode","url":"morse_code_translator.html#decode"},{"doc":"morse_code_translator","title":"decode_to_string","content":"pub fn decode_to_string(\n   input: String,\n   options: DecodeOptions,\n   morse_code_dict: Option(List(#(String, String, List(Bool)))),\n) -&gt; String\n\nSynonyms:\nmorse_code_translator.decode_to_string\nmorse_code_translator decode_to_string","url":"morse_code_translator.html#decode_to_string"},{"doc":"morse_code_translator","title":"encode","content":"pub fn encode(\n   input: String,\n   options: EncodeOptions,\n   morse_code_dict: Option(List(#(String, String, List(Bool)))),\n) -&gt; Result(String, MorseCodeError)\n\nSynonyms:\nmorse_code_translator.encode\nmorse_code_translator encode","url":"morse_code_translator.html#encode"},{"doc":"morse_code_translator","title":"encode_to_string","content":"pub fn encode_to_string(\n   input: String,\n   options: EncodeOptions,\n   morse_code_dict: Option(List(#(String, String, List(Bool)))),\n) -&gt; String\n\nSynonyms:\nmorse_code_translator.encode_to_string\nmorse_code_translator encode_to_string","url":"morse_code_translator.html#encode_to_string"},{"doc":"morse_code_translator","title":"morse_code_translator","content":"","url":"morse_code_translator.html"}]);